==> knews-0.9.3.tar.gz: knews-0.9.3/Widgets/ArtText.h <==
/* This software is Copyright 1995 by Karl-Johan Johnsson
 *
 * Permission is hereby granted to copy, reproduce, redistribute or otherwise
 * use this software as long as: there is no monetary profit gained
 * specifically from the use or reproduction of this software, it is not
 * sold, rented, traded or otherwise marketed, and this copyright notice is
 * included prominently in any copy made. 
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. ANY USE OF THIS
 * SOFTWARE IS AT THE USER'S OWN RISK.
 */
#ifndef _ArtText_h
#define _ArtText_h

#ifndef XtCFirst
#define XtCFirst "First"
#endif
#ifndef XtCShown
#define XtCShown "Shown"
#endif
#ifndef XtCLines
#define XtCLines "Lines"
#endif
#ifndef XtCNAlloc
#define XtCNAlloc "NAlloc"
#endif
#ifndef XtCMargin
#define XtCMargin "Margin"
#endif
#ifndef XtCPreferredLines
#define XtCPreferredLines "PreferredLines"
#endif
#ifndef XtCPreferredColumns
#define XtCPreferredColumns "PreferredColumns"
#endif

#ifndef XtNquoteColor
#define XtNquoteColor "quoteColor"
#endif
#ifndef XtNheaderColor
#define XtNheaderColor "headerColor"
#endif
#ifndef XtNclickableColor
#define XtNclickableColor "clickableColor"
#endif
#ifndef XtNhighlightBackground
#define XtNhighlightBackground "highlightBackground"
#endif
#ifndef XtNhighlightForeground
#define XtNhighlightForeground "highlightForeground"
#endif
#ifndef XtNquoteFont
#define XtNquoteFont "quoteFont"
#endif
#ifndef XtNheaderFont
#define XtNheaderFont "headerFont"
#endif
#ifndef XtNclickableFont
#define XtNclickableFont "clickableFont"
#endif
#ifndef XtNfirst
#define XtNfirst "first"
#endif
#ifndef XtNlines
#define XtNlines "lines"
#endif
#ifndef XtNnAlloc
#define XtNnAlloc "nAlloc"
#endif
#ifndef XtNresizeCallback
#define XtNresizeCallback "resizeCallback"
#endif
#ifndef XtNimageMargin
#define XtNimageMargin "imageMargin"
#endif
#ifndef XtNseparatorMargin
#define XtNseparatorMargin "separatorMargin"
#endif
#ifndef XtNpreferredLines
#define XtNpreferredLines "preferredLines"
#endif
#ifndef XtNpreferredColumns
#define XtNpreferredColumns "preferredColumns"
#endif

typedef struct _ArtTextClassRec*	ArtTextWidgetClass;
typedef struct _ArtTextRec*		ArtTextWidget;

extern WidgetClass artTextWidgetClass;

typedef enum {
    LineTypeOrdinary,
    LineTypeQuoted,
    LineTypeHeader,
    LineTypeSeparator,
    LineTypeImage,
    LineTypeClickable,
    LineTypeSpace
} LineType;

typedef struct {
    long	canvas_length;
    long	slider_length;
    long	slider_position;
} ArtTextReport;

#ifdef _XFUNCPROTOBEGIN
_XFUNCPROTOBEGIN
#endif

extern void ArtTextRot13(Widget);
extern void ArtTextClearLines(Widget);
extern void ArtTextAddLine(Widget, char*, LineType);
extern void ArtTextAppendToLast(Widget, char*);
extern void ArtTextAddSelected(Widget, char*, LineType, long, long);
extern void ArtTextAddSeparator(Widget, Dimension);
extern void ArtTextAddImage(Widget, Pixmap, Dimension, Dimension);
extern void ArtTextAddClickable(Widget, String, XtCallbackProc, XtPointer);
extern void ArtTextAddSpace(Widget, Dimension);
extern void ArtTextGetFirstShownSize(Widget, long*, long*, long*);
extern void ArtTextSetFirst(Widget, long);
extern int ArtTextDumpToFile(Widget, FILE*);

#ifdef _XFUNCPROTOBEGIN
_XFUNCPROTOEND
#endif

#endif /* _ArtText_h */

==> knews-0.9.6-4.tar.gz: knews-0.9.6/Widgets/ArtText.h <==
/* This software is Copyright 1995 by Karl-Johan Johnsson
 *
 * Permission is hereby granted to copy, reproduce, redistribute or otherwise
 * use this software as long as: there is no monetary profit gained
 * specifically from the use or reproduction of this software, it is not
 * sold, rented, traded or otherwise marketed, and this copyright notice is
 * included prominently in any copy made. 
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. ANY USE OF THIS
 * SOFTWARE IS AT THE USER'S OWN RISK.
 */
#ifndef ArtText_h
#define ArtText_h

#ifndef XtCMargin
#define XtCMargin "Margin"
#endif
#ifndef XtCPreferredLines
#define XtCPreferredLines "PreferredLines"
#endif
#ifndef XtCPreferredColumns
#define XtCPreferredColumns "PreferredColumns"
#endif

#ifndef XtNhighlightColor
#define XtNhighlightColor "highlightColor"
#endif
#ifndef XtNresizeCallback
#define XtNresizeCallback "resizeCallback"
#endif
#ifndef XtNseparatorMargin
#define XtNseparatorMargin "separatorMargin"
#endif
#ifndef XtNpreferredLines
#define XtNpreferredLines "preferredLines"
#endif
#ifndef XtNpreferredColumns
#define XtNpreferredColumns "preferredColumns"
#endif
#ifndef XtNurlCallback
#define XtNurlCallback "urlCallback"
#endif

typedef struct ArtTextClassRec*		ArtTextWidgetClass;
typedef struct ArtTextRec*		ArtTextWidget;

extern WidgetClass artTextWidgetClass;

typedef struct {
    long	canvas_length;
    long	slider_length;
    long	slider_position;
} ArtTextReport;

typedef struct {
    const char	*line;
    int		sel_ok;
    long	start;
    long	stop;
} ArtTextUrlReport;

extern void ArtTextRot13(Widget);
extern void ArtTextClearLines(Widget);
extern void ArtTextAddLine(Widget, char*, XFontStruct*, Pixel);
extern void ArtTextAddWLine(Widget, XChar2b*, long, XFontStruct*, Pixel);
extern void ArtTextAppendToLast(Widget, char*);
extern void ArtTextWAppendToLast(Widget, XChar2b*, long);
extern void ArtTextAddSelected(Widget, char*, XFontStruct*, Pixel, long, long);
extern void ArtTextAddSeparator(Widget, int, int);
extern void ArtTextAddClickable(Widget, char*, XFontStruct*, Pixel,
				XtCallbackProc, XtPointer);
extern void ArtTextGetFirstShownSize(Widget, long*, long*, long*);
extern void ArtTextSetFirst(Widget, long);
extern int  ArtTextDumpToFile(Widget, FILE*);
extern void ArtTextAllocLines(Widget, long);

#endif /* ArtText_h */
